@@ -1,21 +1,8 @@
-#' Pipe operator
-#'
-#' See \code{magrittr::\link[magrittr:pipe]{\%>\%}} for details.
-#'
-#' @name %>%
-#' @rdname pipe
-#' @keywords internal
-#' @export
-#' @usage lhs \%>\% rhs
-#' @param lhs A value or the magrittr placeholder.
-#' @param rhs A function call using the magrittr semantics.
-#' @return The result of calling `rhs(lhs)`.
-NULL
-
 reticulate_python_check <- function(
-    ignore = FALSE,
-    unset = FALSE,
-    message = TRUE) {
+  ignore = FALSE,
+  unset = FALSE,
+  message = TRUE
+) {
   if (ignore) {
     return("")
   }
@@ -97,14 +84,15 @@ current_product_connect <- function() {
 }
 
 py_check_installed <- function(
-    envname = NULL,
-    libraries = "",
-    msg = "") {
+  envname = NULL,
+  libraries = "",
+  msg = ""
+) {
   installed_libraries <- py_list_packages(envname = envname)$package
-  find_libs <- map_lgl(libraries, ~ .x %in% installed_libraries)
+  find_libs <- map_lgl(libraries, \(.x) .x %in% installed_libraries)
   if (!all(find_libs)) {
     missing_lib <- libraries[!find_libs]
-    if(is_uv_env()) {
+    if (is_uv_env()) {
       reticulate::py_require(missing_lib)
       return(invisible())
     }
@@ -133,10 +121,10 @@ py_check_installed <- function(
 is_uv_env <- function() {
   is_uv <- FALSE
   base_exe <- path_dir(py_exe())
-  if(path_file(base_exe) == "bin") {
+  if (path_file(base_exe) == "bin") {
     py_base <- path_dir(base_exe)
     cfg_file <- path(py_base, "pyvenv.cfg")
-    if(file_exists(cfg_file)) {
+    if (file_exists(cfg_file)) {
       cfg_contents <- readLines(cfg_file)
       is_uv <- any(grepl("uv = ", cfg_contents))
     }
@@ -145,7 +133,6 @@ is_uv_env <- function() {
 }
 
 
-
 stop_quietly <- function() {
   opt <- options(show.error.messages = FALSE)
   on.exit(options(opt))
