@@ -1,4 +1,80 @@
-skip_if_not_databricks()
+test_that("Find environments works", {
+  withr::with_envvar(
+    new = c(
+      "WORKON_HOME" = use_test_env(),
+      "DATABRICKS_HOST" = "testhost",
+      "DATABRICKS_TOKEN" = "testtoken"
+    ),
+    {
+      local_mocked_bindings(
+        py_exe = function(...) {
+          return(NULL)
+        },
+        virtualenv_starter = function(...) {
+          return(NULL)
+        }
+      )
+      env_path <- test_databricks_stump_env()
+      expect_equal(
+        deploy_find_environment(python = env_path),
+        env_path
+      )
+      expect_error(
+        deploy_find_environment()
+      )
+    }
+  )
+})
+
+test_that("Tests deploy_databricks() happy path cases", {
+  withr::with_envvar(
+    new = c(
+      "WORKON_HOME" = use_test_env(),
+      "DATABRICKS_HOST" = "test",
+      "DATABRICKS_TOKEN" = "test"
+    ),
+    {
+      local_mocked_bindings(
+        deploy = function(...) {
+          return(list(...))
+        },
+        databricks_dbr_version = function(...) {
+          return("17.3")
+        }
+      )
+      expect_snapshot(deploy_databricks())
+      expect_snapshot(deploy_databricks(host = "another1", token = "token"))
+    }
+  )
+})
+
+test_that("Tests deploy_databricks() error cases", {
+  withr::with_envvar(
+    new = c(
+      "WORKON_HOME" = use_test_env(),
+      "DATABRICKS_HOST" = NA,
+      "DATABRICKS_TOKEN" = NA
+    ),
+    {
+      local_mocked_bindings(
+        deploy = function(...) {
+          return(list(...))
+        },
+        databricks_dbr_version = function(...) {
+          return("17.3")
+        }
+      )
+      expect_snapshot(deploy_databricks(), error = TRUE)
+    }
+  )
+})
+
+accounts_df <- function() {
+  data.frame(
+    name = c("my_account", "my_account2", "my_account3"),
+    server = c("my_server", "my_server2", "my_server3")
+  )
+}
 
 test_databricks_deploy_output <- function() {
   list(
@@ -11,6 +87,30 @@ test_databricks_deploy_output <- function() {
   )
 }
 
+test_that("Basic use, passing the cluster's ID", {
+  withr::with_envvar(
+    new = c(
+      "WORKON_HOME" = use_test_env(),
+      "DATABRICKS_HOST" = "test",
+      "DATABRICKS_TOKEN" = "test"
+    ),
+    {
+      local_mocked_bindings(
+        rsconnect_deployApp = function(...) list(...),
+        rsconnect_accounts = function(...) accounts_df(),
+        databricks_dbr_version = function(...) {
+          return("17.3")
+        },
+        py_exe = function(...) test_databricks_stump_env()
+      )
+      expect_equal(
+        deploy_databricks(cluster_id = test_databricks_cluster_id()),
+        test_databricks_deploy_output()
+      )
+    }
+  )
+})
+
 test_databricks_deploy_file <- function() {
   deploy_folder <- path(tempdir(), random_table_name("dep"))
   dir_create(deploy_folder)
@@ -19,12 +119,48 @@ test_databricks_deploy_file <- function() {
   deploy_file
 }
 
-accounts_df <- function() {
-  data.frame(
-    name = c("my_account", "my_account2", "my_account3"),
-    server = c("my_server", "my_server2", "my_server3")
+test_that("Simulates interactive session, selects Yes (1) for both prompts", {
+  withr::with_envvar(
+    new = c(
+      "WORKON_HOME" = use_test_env(),
+      "DATABRICKS_HOST" = "testhost",
+      "DATABRICKS_TOKEN" = "testtoken"
+    ),
+    {
+      deploy_file <- test_databricks_deploy_file()
+      local_mocked_bindings(
+        check_interactive = function(...) TRUE,
+        check_rstudio = function(...) TRUE,
+        menu = function(...) {
+          return(1)
+        },
+        rsconnect_deployApp = function(...) list(...),
+        rsconnect_accounts = function(...) accounts_df(),
+        getSourceEditorContext = function(...) {
+          x <- list()
+          x$path <- as_fs_path(deploy_file)
+          x
+        },
+        py_exe = function(...) test_databricks_stump_env()
+      )
+      out <- test_databricks_deploy_output()
+      out$appDir <- as_fs_path(path_dir(deploy_file))
+
+      expect_equal(
+        deploy_databricks(
+          version = test_databricks_cluster_version(),
+          server = "my_server",
+          account = "my_account",
+          confirm = TRUE
+        ),
+        out
+      )
+    }
   )
-}
+})
+
+skip_if_not_databricks()
+
 
 test_that("Basic use, passing DBR version works", {
   withr::with_envvar(
@@ -45,21 +181,6 @@ test_that("Basic use, passing DBR version works", {
   )
 })
 
-test_that("Basic use, passing the cluster's ID", {
-  withr::with_envvar(
-    new = c("WORKON_HOME" = use_test_env()),
-    {
-      local_mocked_bindings(
-        deployApp = function(...) list(...),
-        accounts = function(...) accounts_df()
-      )
-      expect_equal(
-        deploy_databricks(cluster_id = test_databricks_cluster_id()),
-        test_databricks_deploy_output()
-      )
-    }
-  )
-})
 
 test_that("Use the Cluster ID from environment variable", {
   withr::with_envvar(
@@ -142,40 +263,6 @@ test_that("Fails if no host/token is found", {
   )
 })
 
-test_that("Simulates interactive session, selects Yes (1) for both prompts", {
-  withr::with_envvar(
-    new = c("WORKON_HOME" = use_test_env()),
-    {
-      deploy_file <- test_databricks_deploy_file()
-      local_mocked_bindings(
-        check_interactive = function(...) TRUE,
-        check_rstudio = function(...) TRUE,
-        menu = function(...) {
-          return(1)
-        },
-        deployApp = function(...) list(...),
-        accounts = function(...) accounts_df(),
-        getSourceEditorContext = function(...) {
-          x <- list()
-          x$path <- as_fs_path(deploy_file)
-          x
-        }
-      )
-      out <- test_databricks_deploy_output()
-      out$appDir <- as_fs_path(path_dir(deploy_file))
-
-      expect_equal(
-        deploy_databricks(
-          version = test_databricks_cluster_version(),
-          server = "my_server",
-          account = "my_account",
-          confirm = TRUE
-        ),
-        out
-      )
-    }
-  )
-})
 
 test_that("Simulates interactive session, selects 3 for both prompts", {
   withr::with_envvar(
@@ -212,26 +299,6 @@ test_that("Simulates interactive session, selects 3 for both prompts", {
   )
 })
 
-test_that("Rare cases for finding environments works", {
-  withr::with_envvar(
-    new = c("WORKON_HOME" = use_test_env()),
-    {
-      env_path <- test_databricks_stump_env()
-      local_mocked_bindings(
-        py_exe = function(...) {
-          return(NULL)
-        }
-      )
-      expect_equal(
-        deploy_find_environment(python = env_path),
-        env_path
-      )
-      expect_error(
-        deploy_find_environment()
-      )
-    }
-  )
-})
 
 test_that("Misc deploy tests", {
   expect_error(deploy(), "'backend'")
