@@ -2,16 +2,16 @@ test_that("head() works", {
   tbl_mtcars <- use_test_table_mtcars()
 
   expect_equal(
-    tbl_mtcars %>%
-      head(5) %>%
-      collect() %>%
+    tbl_mtcars |>
+      head(5) |>
+      collect() |>
       nrow(),
     5
   )
 })
 
 test_that("copy_to() works", {
-  tbl_ordered <- use_test_table_mtcars() %>%
+  tbl_ordered <- use_test_table_mtcars() |>
     arrange(mpg, qsec, hp)
 
   expect_snapshot(tbl_ordered)
@@ -21,18 +21,18 @@ test_that("copy_to() works", {
 
 test_that("Sampling functions works", {
   tbl_mtcars <- use_test_table_mtcars()
-  tbl_n <- tbl_mtcars %>%
-    sample_n(5) %>%
-    collect() %>%
-    count() %>%
+  tbl_n <- tbl_mtcars |>
+    sample_n(5) |>
+    collect() |>
+    count() |>
     pull()
 
   expect_equal(tbl_n, 5)
 
-  tbl_frac <- tbl_mtcars %>%
-    sample_frac(0.2) %>%
-    collect() %>%
-    count() %>%
+  tbl_frac <- tbl_mtcars |>
+    sample_frac(0.2) |>
+    collect() |>
+    count() |>
     pull()
 
   expect_lt(tbl_frac, 30)
@@ -44,17 +44,17 @@ test_that("Sampling functions works", {
 })
 
 test_that("Misc functions", {
-  tbl_am <- use_test_table_mtcars() %>%
-    group_by(am) %>%
-    filter(mpg == max(mpg, na.rm = TRUE)) %>%
+  tbl_am <- use_test_table_mtcars() |>
+    group_by(am) |>
+    filter(mpg == max(mpg, na.rm = TRUE)) |>
     select(am)
 
   expect_silent(compute(tbl_am, name = "am"))
 
   expect_silent(compute(tbl_am, name = NULL))
 
-  tbl_join <- use_test_table_mtcars() %>%
-    left_join(tbl_am, by = "am") %>%
+  tbl_join <- use_test_table_mtcars() |>
+    left_join(tbl_am, by = "am") |>
     arrange(mpg, qsec, hp)
 
   expect_error(tbl_ptype(tbl_am))
@@ -80,7 +80,13 @@ test_that("sdf_copy_to() workks", {
     "tbl_pyspark"
   )
   expect_s3_class(
-    sdf_copy_to(sc, test_df, name = "test_df", overwrite = TRUE, repartition = 2),
+    sdf_copy_to(
+      sc,
+      test_df,
+      name = "test_df",
+      overwrite = TRUE,
+      repartition = 2
+    ),
     "tbl_pyspark"
   )
 })
@@ -101,8 +107,8 @@ test_that("I() works", {
   sc <- use_test_spark_connect()
   expect_s3_class(
     {
-      tbl(sc, I("mtcars")) %>%
-        head() %>%
+      tbl(sc, I("mtcars")) |>
+        head() |>
         collect()
     },
     "data.frame"
