@@ -1,34 +1,25 @@
-test_that("Message when RETICULATE_PYTHON is set", {
-  py_to_use <- py_exe()
-  withr::with_envvar(
-    new = c("RETICULATE_PYTHON" = py_to_use),
-    {
-      expect_message(use_envname("newtest", messages = TRUE))
-    }
-  )
-})
-
-env_path <- fs::path(tempdir(), random_table_name("env"))
-
 test_that("Install environment", {
   withr::with_envvar(
-    new = c("WORKON_HOME" = env_path),
+    new = c(
+      "WORKON_HOME" = use_new_temp_env()
+    ),
     {
       expect_output(
-        install_pyspark("3.4", as_job = FALSE, python = Sys.which("python")),
-        as_job = FALSE,
-        python = Sys.which("python")
+        install_pyspark("3.4", as_job = FALSE)
       )
     }
   )
 })
 
 test_that("Use first one", {
+  env_path <- use_new_temp_env()
+  dir_create(path(env_path, "r-sparklyr-pyspark-3.4"))
   withr::with_envvar(
     new = c("WORKON_HOME" = env_path),
     {
       expect_message(
         x <- use_envname(
+          main_library = "pyspark",
           version = "1.1",
           messages = TRUE,
           match_first = TRUE,
@@ -42,6 +33,8 @@ test_that("Use first one", {
 })
 
 test_that("Error if 'use_first' is not TRUE", {
+  env_path <- use_new_temp_env()
+  dir_create(path(env_path, "r-sparklyr-pyspark-3.4"))
   withr::with_envvar(
     new = c("WORKON_HOME" = env_path),
     {
@@ -61,7 +54,7 @@ test_that("Error if 'use_first' is not TRUE", {
 
 test_that("Error if 'use_first' is not TRUE", {
   withr::with_envvar(
-    new = c("WORKON_HOME" = env_path),
+    new = c("WORKON_HOME" = use_new_temp_env()),
     {
       expect_error(
         x <- use_envname(
@@ -77,7 +70,7 @@ test_that("Error if 'use_first' is not TRUE", {
 
 test_that("'Ask to install', simulates menu selection 'Yes'", {
   withr::with_envvar(
-    new = c("WORKON_HOME" = env_path),
+    new = c("WORKON_HOME" = use_new_temp_env()),
     {
       local_mocked_bindings(
         check_interactive = function(...) TRUE,
@@ -89,6 +82,7 @@ test_that("'Ask to install', simulates menu selection 'Yes'", {
       )
       expect_equal(
         use_envname(
+          main_library = "pyspark",
           version = "1.1",
           messages = TRUE,
           match_first = FALSE,
@@ -102,7 +96,7 @@ test_that("'Ask to install', simulates menu selection 'Yes'", {
 
 test_that("'Ask to install', simulates menu selection 'No'", {
   withr::with_envvar(
-    new = c("WORKON_HOME" = env_path),
+    new = c("WORKON_HOME" = use_new_temp_env()),
     {
       local_mocked_bindings(
         check_interactive = function(...) TRUE,
@@ -114,6 +108,7 @@ test_that("'Ask to install', simulates menu selection 'No'", {
       )
       expect_equal(
         use_envname(
+          main_library = "pyspark",
           version = "1.1",
           messages = TRUE,
           match_first = FALSE,
@@ -127,7 +122,7 @@ test_that("'Ask to install', simulates menu selection 'No'", {
 
 test_that("'Ask to install', simulates menu selection 'Cancel'", {
   withr::with_envvar(
-    new = c("WORKON_HOME" = env_path),
+    new = c("WORKON_HOME" = use_new_temp_env()),
     {
       local_mocked_bindings(
         check_interactive = function(...) TRUE,
