@@ -99,3 +99,21 @@ test_that("User agent builder works with Connect env var", {
     }
   )
 })
+
+test_that("User agent builder for Positron", {
+  withr::with_envvar(
+    new = c(
+      "RSTUDIO_PRODUCT" = NA,
+      "POSITRON" = "1",
+      "POSITRON_VERSION" = "12345"
+    ),
+    {
+      expect_equal(
+        build_user_agent(),
+        glue(
+          "sparklyr/{packageVersion('sparklyr')} posit-positron/12345"
+        )
+      )
+    }
+  )
+})
